from xbox.rest import decorators  # noqa: F401


def test_console_exists():
    pass


def test_console_connected():
    pass


def test_require_authentication():
    pass
